@@ -20,9 +20,11 @@ icon_theme = Gtk.IconTheme.get_default()
 
 #ICONS = "/usr/share/icons/antiX-numix-bevel"
 #ICONS = "/usr/share/icons/antiX-numix-square"
-ICONS = "/usr/share/icons/antiX-papirus"
+#ICONS = "/usr/share/icons/antiX-papirus"
 #ICONS = "/usr/share/icons/antiX-faenza"
 #ICONS = "/usr/share/icons/antiX-moka"
+ICONS = "/usr/share/icons/antiX-qogir"
+#ICONS = "/usr/share/icons/antiX-kora"
 
 gettext.install(domain = "desktop-session-exit")
 
@@ -95,6 +97,8 @@ class mainWindow(Gtk.Window):
         self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
         self.set_title(_("Exit Session"))
         self.connect("key-press-event", self.keypress)
+        self.set_keep_above(True)
+        self.stick()
         self.show()
         
         self.grid = Gtk.Grid()
